@@ -1,7 +1,7 @@
 """
-This is aiosteampy module.
+This is `aiosteampy` package.
 """
 
-from .utils import *
+from .exceptions import ApiError, LoginError, ConfirmationError, CaptchaRequired, SessionExpired
 from .constants import Game, STEAM_URL, Currency, Language, TradeOfferStatus, MarketListingStatus
 from .client import SteamClient, SteamPublicClient
